package com.srs.comprehensive.mapper;

import java.util.List;

import com.github.yulichang.base.MPJBaseMapper;
import com.srs.comprehensive.domain.ViewStuInfo;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;

/**
 * 学生信息视图Mapper接口
 *
 * @author srs
 * @date 2024-04-07
 */
@Mapper
public interface ViewStuInfoMapper extends MPJBaseMapper<ViewStuInfo> {
    /**
     * 查询学生信息视图
     *
     * @param stuId 学生信息视图主键
     * @return 学生信息视图
     */
    public ViewStuInfo selectViewStuInfoByStuId(Long stuId);

    /**
     * 查询学生信息视图列表
     *
     * @param viewStuInfo 学生信息视图
     * @return 学生信息视图集合
     */
    List<ViewStuInfo> selectViewStuInfoList(ViewStuInfo viewStuInfo);

    /**
     * 新增学生信息视图
     *
     * @param viewStuInfo 学生信息视图
     * @return 结果
     */
    int insertViewStuInfo(ViewStuInfo viewStuInfo);

    /**
     * 修改学生信息视图
     *
     * @param viewStuInfo 学生信息视图
     * @return 结果
     */
    int updateViewStuInfo(ViewStuInfo viewStuInfo);

    /**
     * 删除学生信息视图
     *
     * @param stuId 学生信息视图主键
     * @return 结果
     */
    int deleteViewStuInfoByStuId(Long stuId);

    /**
     * 批量删除学生信息视图
     *
     * @param stuIds 需要删除的数据主键集合
     * @return 结果
     */
    int deleteViewStuInfoByStuIds(Long[] stuIds);
}
